/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
export default {
  addTeam: 'Add Team',
  team: 'Team',
  modifyTeam: 'Modify Team',
  deleteTeam: 'Delete Team',
  deletePopConfirm: 'Are you sure delete this team ?',
  add: 'Add',
  success: 'successful',
  fail: 'failed',
  table: {
    title: 'Team List',
    teamName: 'Team',
    teamNamePlaceholder: 'please enter Team Name',
    description: 'Description',
    descriptionMessage: 'exceeds maximum length limit of 100 characters',
    teamMessage: 'teamName must be at least 4 characters',
  },
};
